########
 Models
########

*********************************
 Encoder Processor Decoder Model
*********************************

The model defines a graph neural network architecture with configurable
encoder, processor, and decoder.

.. automodule:: anemoi.models.models.encoder_processor_decoder
   :members:
   :no-undoc-members:
   :show-inheritance:
